@@ -33,6 +33,8 @@
 #include <config.h>
 #include "peony-window-private.h"
 
+#include <webkit2/webkit2.h>
+
 #include "peony-actions.h"
 #include "peony-application.h"
 #include "peony-bookmarks-window.h"
@@ -89,6 +91,9 @@ static void mouse_forward_button_changed	     (gpointer                  callbac
 static void use_extra_mouse_buttons_changed          (gpointer                  callback_data);
 static PeonyWindowSlot *create_extra_pane         (PeonyNavigationWindow *window);
 
+static void preview_file_changed_callback(PeonyWindowInfo *window_info, gpointer data);
+static void office_format_trans_ready_callback(PeonyWindowInfo *window_info, gpointer data);
+static void show_pdf_file_callback(PeonyWindowInfo *window_info, gpointer data);
 
 G_DEFINE_TYPE (PeonyNavigationWindow, peony_navigation_window, PEONY_TYPE_WINDOW)
 #define parent_class peony_navigation_window_parent_class
@@ -144,6 +149,8 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     GtkImage *listView_image;
     GtkWidget *iconView_button;
     GtkWidget *listView_button;
+
+    //pdf_viewer_init();
 	
     win = PEONY_WINDOW (window);
 
@@ -189,6 +196,14 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     gtk_paned_pack1 (GTK_PANED(hpaned), pane->widget, TRUE, FALSE);
     gtk_widget_show (pane->widget);
 
+    //GtkWidget *test = test_widget_new();
+    //open_file_cb(test,"/home/lanyue/ui");
+    //window->details->test_widget = test_widget_new();
+    //open_file_cb(window->details->test_widget, "/home/lanyue/ui");
+    //window->details->test_widget = gtk_scrolled_window_new(NULL,NULL);
+    //gtk_paned_pack2 (GTK_PANED(hpaned), window->details->test_widget, TRUE, FALSE);
+    //gtk_widget_show (window->details->test_widget);
+
     /* this has to be done after the location bar has been set up,
      * but before menu stuff is being called */
     peony_window_set_active_pane (win, PEONY_WINDOW_PANE (pane));
@@ -233,6 +248,11 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     gtk_widget_show (add_toolbar_vbox);
     gtk_widget_set_size_request (add_toolbar_vbox,36,36);
 
+    GtkWidget *separator= gtk_hseparator_new();
+    gtk_grid_attach (window->toolbar_table,
+                        separator,
+	                    0,0,3,1);
+
     gtk_grid_attach (window->toolbar_table,
                         add_toolbar_vbox,
 	                    0,1,1,1);
@@ -269,6 +289,9 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
                               "changed::" PEONY_PREFERENCES_ALWAYS_USE_BROWSER,
                               G_CALLBACK(always_use_browser_changed),
                               window);
+
+    //pdf_viewer_init();
+    office_utils_conncet_window_info (PEONY_WINDOW_INFO (window));
 }
 
 static void
@@ -651,6 +674,11 @@ peony_navigation_window_button_press_event (GtkWidget *widget,
 static void
 peony_navigation_window_destroy (GtkWidget *object)
 {
+    char* filename;
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (preview_file_changed_callback), filename);
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (office_format_trans_ready_callback), NULL);
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (show_pdf_file_callback), NULL);
+
     PeonyNavigationWindow *window;
 
     window = PEONY_NAVIGATION_WINDOW (object);
@@ -665,6 +693,26 @@ peony_navigation_window_destroy (GtkWidget *object)
     window->details->content_paned = NULL;
     window->details->split_view_hpane = NULL;
 
+    //gtk_widget_destroy(window->details->test_widget);
+    window->details->test_widget = NULL;
+    window->details->gtk_source_widget = NULL;
+    window->details->pdf_swindow = NULL;
+    window->details->pdf_view = NULL;
+    window->details->web_swindow = NULL;
+    window->details->web_view = NULL;
+    window->details->empty_window = NULL;
+    window->details->hint_view = NULL;
+    window->details->current_preview_filename = NULL;
+
+    //global_window = NULL;
+    //global_preview_filename = NULL;
+    //global_preview_office2pdf_filename = NULL;
+    //global_preview_excel2html_filename = NULL;
+    //global_test_widget = NULL;
+
+    //pdf_viewer_shutdown();    
+    clean_cache_files_anyway ();
+
     GTK_WIDGET_CLASS (parent_class)->destroy (object);
 }
 
@@ -1366,86 +1414,280 @@ create_extra_pane (PeonyNavigationWindow *window)
     return slot;
 }
 
+static void show_pdf_file_callback (PeonyWindowInfo *window_info, gpointer data) {
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    if (is_pdf_file (window->details->current_preview_filename)) {
+        set_pdf_preview_widget_file_by_filename(window->details->pdf_view, window->details->current_preview_filename);
+        gtk_widget_hide (window->details->empty_window);
+        gtk_widget_show_all (window->details->pdf_swindow);
+        gtk_widget_hide (window->details->test_widget);
+        gtk_widget_hide (window->details->web_swindow);
+    }
+}
+
+static void office_format_trans_ready_callback(PeonyWindowInfo *window_info, gpointer data){
+    //printf("office2pdf/html done\n");
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    char* current_preview_filename = window->details->current_preview_filename;
+    char* pending_preview_filename = window->details->pending_preview_filename;
+    char* current_previewing_office_filename = window->details->current_previewing_office_filename;
+
+    //printf("current: %s, pending: %s current office:%s\n",current_preview_filename , pending_preview_filename, current_previewing_office_filename);
+
+    if (!current_preview_filename){
+        return;
+    }
+
+    GFile *file;
+    file = g_file_new_for_path (pending_preview_filename);
+    if (!g_file_query_exists (file, NULL)){
+        //printf ("file %s doesn't exist\n", pending_preview_filename);
+        return;
+    }
+
+    if(!g_str_equal(current_preview_filename, current_previewing_office_filename)){
+        return;
+    }
+
+    if (filename_has_suffix(pending_preview_filename,".pdf")) {
+        set_pdf_preview_widget_file_by_filename (window->details->pdf_view, pending_preview_filename);
+        gtk_widget_hide (window->details->empty_window);
+        gtk_widget_show_all (window->details->pdf_swindow);
+        gtk_widget_hide (window->details->test_widget);
+        gtk_widget_hide (window->details->web_swindow);
+    } else if (filename_has_suffix(pending_preview_filename,".html")) {
+        gchar *uri;
+        uri = g_strdup_printf("file://%s", pending_preview_filename);
+        //printf("load uri: %s",uri);
+        webkit_web_view_set_zoom_level (window->details->web_view, 1.50);
+        webkit_web_view_load_uri (WEBKIT_WEB_VIEW (window->details->web_view), uri);
+        g_free(uri);
+        gtk_widget_hide (window->details->empty_window);
+        gtk_widget_hide (window->details->pdf_swindow);
+        gtk_widget_hide (window->details->test_widget);
+        gtk_widget_show_all (window->details->web_swindow);
+    }
+
+}
+
+static void preview_file_changed_callback(PeonyWindowInfo *window_info, gpointer data){
+
+    if (peony_window_info_get_window_type (window_info) != PEONY_WINDOW_NAVIGATION){
+        //printf ("is not navigation\n");
+        return;
+    }
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    if (!window->details->preview_hbox) {
+        //printf("split view is not init!\n");
+        return;
+    }
+
+    if((char*)data == "null"){
+        //printf ("null\n\n\n");
+        gtk_label_set_label(window->details->hint_view, _("Select the file you want to preview"));
+	    gtk_widget_show_all(window->details->empty_window);
+	    gtk_widget_hide(window->details->pdf_swindow);
+	    gtk_widget_hide(window->details->test_widget);
+        gtk_widget_hide(window->details->web_swindow);
+        window->details->current_preview_filename = NULL;
+        return;
+    } 
+
+    if (window->details->pending_preview_filename){
+        //printf("has tmp file before: %s\n", window->details->pending_preview_filename);
+        //g_remove (window->details->pending_preview_filename);
+        clean_cache_files_anyway();
+        free (window->details->pending_preview_filename);
+        window->details->pending_preview_filename = NULL;
+    }
+
+    if (window->details->current_preview_filename) {
+        g_free (window->details->current_preview_filename);
+    }
+
+    //printf ("preview start:\n");
+    window->details->current_preview_filename = g_strdup (data);
+
+    if(is_text_type((char*)data)){
+	    open_file_cb(window->details->gtk_source_widget,(char*)data);
+        gtk_widget_hide (window->details->empty_window);
+        gtk_widget_hide (window->details->pdf_swindow);
+        gtk_widget_hide (window->details->web_swindow);
+        gtk_widget_show_all (window->details->test_widget);
+    } else if (is_image_type((char*)data)) {
+        //printf("is image type\n");
+        gchar *uri;
+        uri = g_strdup_printf("file://%s", data);
+        //printf("load uri: %s",uri);
+        webkit_web_view_set_zoom_level (window->details->web_view, 1.00);
+        webkit_web_view_load_uri (WEBKIT_WEB_VIEW (window->details->web_view), uri);
+        g_free(uri);
+        gtk_widget_hide (window->details->empty_window);
+        gtk_widget_hide (window->details->pdf_swindow);
+        gtk_widget_hide (window->details->test_widget);
+        gtk_widget_show_all (window->details->web_swindow);
+    }  else if (is_pdf_type((char*)data)) {
+        //printf("is pdf type\n");
+        window_delay_set_pdf_preview_widget_file_by_filename (PEONY_WINDOW_INFO (window), (char*)data);
+        /*
+        set_pdf_preview_widget_file_by_filename(window->details->pdf_view,(char*)data);
+        gtk_widget_hide (window->details->empty_window);
+        gtk_widget_show_all (window->details->pdf_swindow);
+        gtk_widget_hide (window->details->test_widget);
+        gtk_widget_hide (window->details->web_swindow);
+        */
+
+        gtk_label_set_label (window->details->hint_view, _("Loading..."));
+        gtk_widget_show_all (window->details->empty_window);
+	    gtk_widget_hide (window->details->pdf_swindow);
+	    gtk_widget_hide (window->details->test_widget);
+        gtk_widget_hide (window->details->web_swindow);
+    } else if (is_office_file((char*) data)) {
+
+        //window->details->pending_preview_filename = get_pending_preview_filename(window->details->current_preview_filename);
+        //window->details->current_preview_filename = g_strdup (data);
+        char* fakename = get_pending_preview_filename (window->details->current_preview_filename);
+        window->details->current_previewing_office_filename = g_strdup (data);
+        //printf ("current_previewing_office_filename: %s ", peony_navigation_window_get_current_previewing_office_file_by_window_info (PEONY_WINDOW_INFO (window)));
+
+        //we'll sheduel a unoconv child progress to tran office file to pdf/html first, this will be delayed for a few times.
+        //the current preview filename is the file which we selecting now.
+        //the pending preview filename is a tmp pdf/thml file that trans by the child prog.
+        //the current_previewing_office_filename is simillar to current preview filename, but it just recored the newest office file which we select.
+        //when office trans ready, we'll compare the current_previewing_filename and current_previewing_office_filename,
+        //if they are not same, we won't show the office preview widget.
+
+        //printf ("prepare_to_trans_file_by_window\n");
+
+        prepare_to_trans_file_by_window (PEONY_WINDOW_INFO (window), window->details->current_previewing_office_filename);
+
+        if (fakename)
+            gtk_label_set_label (window->details->hint_view, _("Loading..."));
+        else
+            gtk_label_set_label (window->details->hint_view, _("Can't preview this file"));
+
+        g_free (fakename);
+
+	    gtk_widget_show_all (window->details->empty_window);
+	    gtk_widget_hide (window->details->pdf_swindow);
+	    gtk_widget_hide (window->details->test_widget);
+        gtk_widget_hide (window->details->web_swindow);
+    } else {
+        //printf("can't preview this file\n");
+        gtk_label_set_label (window->details->hint_view, _("Can't preview this file"));
+	    gtk_widget_show_all (window->details->empty_window);
+	    gtk_widget_hide (window->details->pdf_swindow);
+	    gtk_widget_hide (window->details->test_widget);
+        gtk_widget_hide (window->details->web_swindow);
+    }
+
+}
+
+static gboolean do_not_show_right_click_menu_callback (WebKitWebView *web_view) {
+    return TRUE;
+}
+
 void
 peony_navigation_window_split_view_on (PeonyNavigationWindow *window)
 {
-    PeonyWindow *win;
-    PeonyNavigationWindowPane *pane;
-    PeonyWindowSlot *slot, *old_active_slot;
-    GFile *location;
-    GtkAction *action;
+    //return;
+    pdf_viewer_init();
 
-    win = PEONY_WINDOW (window);
+	//cause we may switch to the old window, we should sure that if the hbox is existed.
+	if(window->details->preview_hbox)
+		goto last;
+    else {
+        //create a hbox for preview views
+        window->details->preview_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
 
-    old_active_slot = peony_window_get_active_slot (win);
-    slot = create_extra_pane (window);
-    pane = PEONY_NAVIGATION_WINDOW_PANE (slot->pane);
+        //add text widget to preview_hbox
+        window->details->test_widget = gtk_scrolled_window_new(NULL,NULL);
+        //global_test_widget = test_widget_new();
+        window->details->gtk_source_widget = test_widget_new();//global_test_widget;
+        gtk_container_add (GTK_CONTAINER (window->details->test_widget), GTK_WIDGET (window->details->gtk_source_widget));
+        gtk_box_pack_start (GTK_BOX(window->details->preview_hbox), GTK_WIDGET(window->details->test_widget), TRUE, TRUE, 0);
+        
+        //add pdf widget to preview_hbox
+        window->details->pdf_swindow = gtk_scrolled_window_new(NULL,NULL);
+        window->details->pdf_view = pdf_preview_widget_new();        
+        gtk_container_add (GTK_CONTAINER (window->details->pdf_swindow), window->details->pdf_view);        
+        gtk_box_pack_start (GTK_BOX(window->details->preview_hbox), GTK_WIDGET(window->details->pdf_swindow), TRUE, TRUE, 0);
+
+        //add web widget to preview_hbox
+        window->details->web_swindow = gtk_scrolled_window_new(NULL,NULL);
+        window->details->web_view = webkit_web_view_new();
+        WebKitSettings *settings = webkit_settings_new ();
+        webkit_settings_set_enable_page_cache (settings, FALSE);
+        webkit_settings_set_zoom_text_only (settings, TRUE);
+        webkit_settings_set_enable_javascript (settings, TRUE);
+        webkit_settings_set_javascript_can_access_clipboard (settings, TRUE);
+        //g_object_set (G_OBJECT(settings), "context-menu", FALSE, NULL);
+        g_signal_connect (window->details->web_view, "context-menu", G_CALLBACK (do_not_show_right_click_menu_callback), NULL);
+        webkit_web_view_set_settings (window->details->web_view, settings);
+        g_object_unref (settings);
+        //webkit_web_view_set_zoom_level (window->details->web_view, 1.50);
+        gtk_container_add (GTK_CONTAINER(window->details->web_swindow), GTK_WIDGET(window->details->web_view));
+        gtk_box_pack_start (GTK_BOX(window->details->preview_hbox), GTK_WIDGET(window->details->web_swindow), TRUE, TRUE, 0);
+
+        //add empty widget to preview_hbox
+        window->details->empty_window = gtk_scrolled_window_new(NULL,NULL);
+        window->details->hint_view = gtk_label_new (_("Select the file you want to preview"));    
+        gtk_box_pack_start (GTK_BOX(window->details->preview_hbox), GTK_WIDGET(window->details->empty_window), TRUE, TRUE, 0);
+        gtk_container_add (GTK_CONTAINER(window->details->empty_window), GTK_WIDGET(window->details->hint_view));
+
+        //pack the preview_hbox to the split_view_hpane
+        gtk_paned_pack2 (GTK_PANED(window->details->split_view_hpane), window->details->preview_hbox, TRUE, FALSE);
 
-    location = NULL;
-    if (old_active_slot != NULL)
-    {
-        location = peony_window_slot_get_location (old_active_slot);
-        if (location != NULL)
-        {
-            if (g_file_has_uri_scheme (location, "x-peony-search"))
-            {
-                g_object_unref (location);
-                location = NULL;
-            }
-        }
-    }
-    if (location == NULL)
-    {
-        location = g_file_new_for_path (g_get_home_dir ());
     }
+    
 
-    peony_window_slot_go_to (slot, location, FALSE);
-    g_object_unref (location);
+last:
+    gtk_label_set_label (window->details->hint_view, _("Select the file you want to preview"));
+    gtk_widget_show_all (window->details->preview_hbox);
+    gtk_widget_hide (window->details->test_widget);
+    gtk_widget_hide (window->details->pdf_swindow);
+    gtk_widget_hide (window->details->web_swindow);
+    
+    char* preview_filename; 
 
-    action = gtk_action_group_get_action (PEONY_NAVIGATION_WINDOW (PEONY_WINDOW_PANE (pane)->window)->details->navigation_action_group,
-                                          PEONY_ACTION_SHOW_HIDE_LOCATION_BAR);
-    if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
-    {
-        peony_navigation_window_pane_show_location_bar (pane, TRUE);
-    }
-    else
-    {
-        peony_navigation_window_pane_hide_location_bar (pane, TRUE);
-    }
+    g_signal_connect (PEONY_WINDOW_INFO(window),
+                          "preview_file",
+                          G_CALLBACK (preview_file_changed_callback), preview_filename
+                          );
+
+    g_signal_connect (PEONY_WINDOW_INFO(window),
+                          "office_trans_ready",
+                          G_CALLBACK (office_format_trans_ready_callback), NULL
+                          );
+
+    g_signal_connect (PEONY_WINDOW_INFO(window),
+                          "show_pdf_file",
+                          G_CALLBACK (show_pdf_file_callback), NULL
+                          );
+
+    window->details->is_split_view_showing = TRUE;
 }
 
 void
 peony_navigation_window_split_view_off (PeonyNavigationWindow *window)
 {
-    PeonyWindow *win;
-    PeonyWindowPane *pane, *active_pane;
-    GList *l, *next;
+    gtk_widget_hide (window->details->preview_hbox);
+    char *data;
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(preview_file_changed_callback),data);
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(office_format_trans_ready_callback),NULL);
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(show_pdf_file_callback),NULL);
 
-    win = PEONY_WINDOW (window);
-
-    g_return_if_fail (win);
-
-    active_pane = win->details->active_pane;
-
-    /* delete all panes except the first (main) pane */
-    for (l = win->details->panes; l != NULL; l = next)
-    {
-        next = l->next;
-        pane = l->data;
-        if (pane != active_pane)
-        {
-            peony_window_close_pane (pane);
-        }
-    }
-
-    peony_navigation_window_update_show_hide_menu_items (window);
+    window->details->is_split_view_showing = FALSE;
     peony_navigation_window_update_split_view_actions_sensitivity (window);
+    
+    clean_cache_files_anyway ();
 }
 
 gboolean
 peony_navigation_window_split_view_showing (PeonyNavigationWindow *window)
 {
-    return g_list_length (PEONY_WINDOW (window)->details->panes) > 1;
+    return window->details->is_split_view_showing ;
 }
 
 void
@@ -1468,3 +1710,103 @@ peony_find_duplicate_files (PeonyNavigationWindow *window,GList *pListRes)
 	return ;
 }
 
+void     peony_navigation_window_set_current_preview_file_by_window_info (PeonyWindowInfo *window_info, char* filename) {
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    
+    if (window->details->current_preview_filename) {
+        g_free (window->details->current_preview_filename);
+    }
+    if (filename) {
+        window->details->current_preview_filename = g_strdup (filename);    
+    } else {
+        window->details->current_preview_filename = NULL;
+    }
+}
+
+char*    peony_navigation_window_get_current_preview_file_by_window_info (PeonyWindowInfo *window_info){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    return window->details->current_preview_filename;
+}
+
+void     peony_navigation_window_set_current_previewing_office_file_by_window_info (PeonyWindowInfo *window_info, char* filename){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+
+    if (window->details->current_previewing_office_filename) {
+        g_free (window->details->current_previewing_office_filename);
+    }
+    if (filename) {
+        window->details->current_previewing_office_filename = g_strdup (filename);    
+    } else {
+        window->details->current_previewing_office_filename = NULL;
+    }
+}
+
+char*    peony_navigation_window_get_current_previewing_office_file_by_window_info (PeonyWindowInfo *window_info){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    return window->details->current_previewing_office_filename;
+}
+
+void     peony_navigation_window_set_pending_preview_file_by_window_info (PeonyWindowInfo *window_info, char* filename){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+
+    if (window->details->pending_preview_filename) {
+        g_free (window->details->pending_preview_filename);
+    }
+    if (filename) {
+        window->details->pending_preview_filename = g_strdup (filename);    
+    } else {
+        window->details->pending_preview_filename = NULL;
+    }
+}
+
+char*    peony_navigation_window_get_pending_preview_file_by_window_info (PeonyWindowInfo *window_info){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    return window->details->pending_preview_filename;
+}
+
+void     peony_navigation_window_set_loading_office_file_by_window_info (PeonyWindowInfo *window_info, char* filename){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+
+    if (window->details->loading_office_filename) {
+        g_free (window->details->loading_office_filename);
+    }
+    if (filename) {
+        window->details->loading_office_filename = g_strdup (filename);    
+    } else {
+        window->details->loading_office_filename = NULL;
+    }
+}
+
+char*    peony_navigation_window_get_loading_office_file_by_window_info (PeonyWindowInfo *window_info){
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    return window->details->loading_office_filename;
+}
+
+void     peony_navigation_window_set_latest_pdf_preview_file_by_window_info (PeonyWindowInfo *window_info, char* filename) {
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+
+    if (window->details->latest_pdf_flename) {
+        g_free (window->details->latest_pdf_flename);
+    }
+    if (filename) {
+        window->details->latest_pdf_flename = g_strdup (filename);    
+    } else {
+        window->details->latest_pdf_flename = NULL;
+    }
+}
+
+char*    peony_navigation_window_get_latest_preview_file_by_window_info (PeonyWindowInfo *window_info) {
+
+    PeonyNavigationWindow *window = PEONY_NAVIGATION_WINDOW (window_info);
+    return window->details->latest_pdf_flename;
+}
+
