@@ -1655,7 +1655,7 @@ help_button_callback (GtkWidget *widget, GtkWidget *property_browser)
     GtkWidget *dialog;
 
     gtk_show_uri (gtk_widget_get_screen (property_browser),
-                  "help:ukui-user-guide/gospeony-50",
+                  "help:ubuntu-kylin-help/files",
                   gtk_get_current_event_time (), &error);
 
     if (error)
