@@ -1,6 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * Copyright (C) 2005 Red Hat, Inc.
+ * Copyright (C) 2018, Tianjin KYLIN Information Technology Co., Ltd.
  *
  * Peony is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,6 +19,7 @@
  * Boston, MA 02110-1301, USA.
  *
  * Author: Alexander Larsson <alexl@redhat.com>
+ * Modified by: liupeng <liupeng@kylinos.cn>
  *
  */
 
@@ -1079,6 +1081,11 @@ finish_first_line (PeonyQueryEditor *editor, GtkWidget *hbox, gboolean use_go)
 {
     GtkWidget *button, *image;
 
+	if(TRUE == get_search_bar_duplicate(editor->details->bar))
+	{
+		return;
+	}
+	
     button = gtk_button_new ();
     image = gtk_image_new_from_icon_name ("add",
                                       GTK_ICON_SIZE_SMALL_TOOLBAR);
@@ -1158,7 +1165,14 @@ setup_external_entry (PeonyQueryEditor *editor, GtkWidget *entry)
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (editor->details->visible_vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new (_("Search results"));
+	if(TRUE == get_search_bar_duplicate(editor->details->bar))
+	{
+		label = gtk_label_new (_("Find results"));
+	}
+	else
+	{
+    	label = gtk_label_new (_("Search results"));
+	}
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
@@ -1416,7 +1430,10 @@ peony_query_editor_set_query (PeonyQueryEditor *editor, PeonyQuery *query)
     {
         text = g_strdup ("");
     }
-
+	if(TRUE == get_query_duplicate(query))
+	{
+		return;
+	}
     editor->details->change_frozen = TRUE;
     gtk_entry_set_text (GTK_ENTRY (editor->details->entry), text);
 
